@@ -15,19 +15,37 @@
 # limitations under the License.
 #
 
+from warnings import warn
 from pyspark import keyword_only
-
 from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OTreeBasedSupervisedAlgoBase import H2OTreeBasedSupervisedAlgoBase
-from ai.h2o.sparkling.ml.params import H2OXGBoostParams
+from ai.h2o.sparkling.ml.algos.H2OTreeBasedSupervisedAlgorithm import H2OTreeBasedSupervisedAlgorithm
+from ai.h2o.sparkling.ml.models.H2OXGBoostMOJOModel import H2OXGBoostMOJOModel
+from ai.h2o.sparkling.ml.params.H2OXGBoostParams import H2OXGBoostParams
+from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
+from ai.h2o.sparkling.ml.algos.DistributionBasedH2OTrainFramePreparation import DistributionBasedH2OTrainFramePreparation
 
 
-class H2OXGBoost(H2OXGBoostParams, H2OTreeBasedSupervisedAlgoBase):
+class H2OXGBoost(H2OXGBoostParams, H2OCommonParams, H2OTreeBasedSupervisedAlgorithm, DistributionBasedH2OTrainFramePreparation):
 
     @keyword_only
     def __init__(self,
-                 quietMode=True,
+                 monotoneConstraints={},
+                 calibrationDataFrame=None,
+                 ignoredCols=None,
+                 columnsToCategorical=[],
+                 withContributions=False,
+                 withLeafNodeAssignments=False,
+                 namedMojoOutputColumns=True,
+                 convertInvalidNumbersToNa=False,
+                 detailedPredictionCol="detailed_prediction",
+                 validationDataFrame=None,
+                 featuresCols=[],
+                 predictionCol="prediction",
+                 convertUnknownCategoricalLevelsToNa=False,
+                 splitRatio=1.0,
+                 withStageResults=False,
+                 withDetailedPredictionCol=True,
                  ntrees=50,
                  maxDepth=6,
                  minRows=1.0,
@@ -40,61 +58,67 @@ class H2OXGBoost(H2OXGBoostParams, H2OTreeBasedSupervisedAlgoBase):
                  colSampleByLevel=1.0,
                  colSampleRatePerTree=1.0,
                  colSampleByTree=1.0,
+                 colSampleByNode=1.0,
                  maxAbsLeafnodePred=0.0,
                  maxDeltaStep=0.0,
                  scoreTreeInterval=0,
+                 seed=-1,
                  minSplitImprovement=0.0,
                  gamma=0.0,
                  nthread=-1,
+                 buildTreeOneNode=False,
+                 saveMatrixDirectory=None,
+                 calibrateModel=False,
                  maxBins=256,
                  maxLeaves=0,
-                 minSumHessianInLeaf=100.0,
-                 minDataInLeaf=0.0,
                  treeMethod="auto",
                  growPolicy="depthwise",
                  booster="gbtree",
-                 dmatrixType="auto",
-                 regLambda=0.0,
+                 regLambda=1.0,
                  regAlpha=0.0,
+                 quietMode=True,
                  sampleType="uniform",
                  normalizeType="tree",
                  rateDrop=0.0,
                  oneDrop=False,
                  skipDrop=0.0,
-                 gpuId=0,
+                 dmatrixType="auto",
                  backend="auto",
+                 gpuId=None,
+                 interactionConstraints=None,
                  modelId=None,
+                 nfolds=0,
+                 keepCrossValidationModels=True,
                  keepCrossValidationPredictions=False,
                  keepCrossValidationFoldAssignment=False,
-                 parallelizeCrossValidation=True,
                  distribution="AUTO",
+                 tweediePower=1.5,
                  labelCol="label",
-                 foldCol=None,
                  weightCol=None,
                  offsetCol=None,
-                 splitRatio=1.0,
-                 seed=-1,
-                 nfolds=0,
-                 allStringColumnsToCategorical=True,
-                 columnsToCategorical=[],
-                 predictionCol="prediction",
-                 detailedPredictionCol="detailed_prediction",
-                 withDetailedPredictionCol=False,
-                 featuresCols=[],
-                 convertUnknownCategoricalLevelsToNa=False,
-                 convertInvalidNumbersToNa=False,
-                 namedMojoOutputColumns=True,
-                 monotoneConstraints={},
+                 foldCol=None,
+                 foldAssignment="AUTO",
+                 categoricalEncoding="AUTO",
+                 ignoreConstCols=True,
+                 scoreEachIteration=False,
                  stoppingRounds=0,
+                 maxRuntimeSecs=0.0,
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
-                 withContributions=False,
                  gainsliftBins=-1,
-                 withLeafNodeAssignments=False,
-                 **DeprecatedParams):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OXGBoost, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OXGBoost", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
+
+        if 'interactionPairs' in kwargs:
+            warn("Interaction pairs are not supported!")
         self._set(**kwargs)
+        self._transfer_params_to_java()
+
+    def _create_model(self, javaModel):
+        return H2OXGBoostMOJOModel(javaModel)
