@@ -30,9 +30,7 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
-                 keepBinaryModels=False,
                  withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -43,6 +41,7 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
+                 withDetailedPredictionCol=True,
                  ntrees=50,
                  maxDepth=6,
                  minRows=1.0,
@@ -83,7 +82,6 @@ class H2OXGBoostRegressor(H2OXGBoost):
                  backend="auto",
                  gpuId=None,
                  interactionConstraints=None,
-                 scalePosWeight=1.0,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
