@@ -22,7 +22,6 @@ from ai.h2o.sparkling.ml.algos.classification import H2OGBMClassifier
 from ai.h2o.sparkling.ml.algos.classification import H2OXGBoostClassifier
 from ai.h2o.sparkling.ml.algos.classification import H2ODeepLearningClassifier
 from ai.h2o.sparkling.ml.algos.classification import H2ODRFClassifier
-from ai.h2o.sparkling.ml.algos.classification import H2ORuleFitClassifier
 
 __all__ = [
     "H2OAutoMLClassifier",
@@ -31,5 +30,4 @@ __all__ = [
     "H2OGBMClassifier",
     "H2OXGBoostClassifier",
     "H2ODeepLearningClassifier",
-    "H2ODRFClassifier",
-    "H2ORuleFitClassifier"]
+    "H2ODRFClassifier"]
